C E F G I P R 
All Classes All Packages

C

ConfigurationPropertyAnnotationProcessor - Class in io.microsphere.annotation.processor
The Processor for the ConfigurationProperty annotation
ConfigurationPropertyAnnotationProcessor() - Constructor for class io.microsphere.annotation.processor.ConfigurationPropertyAnnotationProcessor
 

E

exists(FileObject) - Static method in class io.microsphere.annotation.processor.ResourceProcessor
 

F

FilerProcessor - Class in io.microsphere.annotation.processor
A processor class that provides safe and exception-handled operations for interacting with the Filer in an annotation processing environment.
FilerProcessor(ProcessingEnvironment) - Constructor for class io.microsphere.annotation.processor.FilerProcessor
 

G

getJavaFileManager() - Method in class io.microsphere.annotation.processor.FilerProcessor
Get the JavaFileManager
getResource(String, boolean) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
getSupportedSourceVersion() - Method in class io.microsphere.annotation.processor.ConfigurationPropertyAnnotationProcessor
 

I

init(ProcessingEnvironment) - Method in class io.microsphere.annotation.processor.ConfigurationPropertyAnnotationProcessor
 
io.microsphere.annotation.processor - package io.microsphere.annotation.processor
 

P

process(Set<? extends TypeElement>, RoundEnvironment) - Method in class io.microsphere.annotation.processor.ConfigurationPropertyAnnotationProcessor
 
processInFiler(ThrowableFunction<Filer, T>) - Method in class io.microsphere.annotation.processor.FilerProcessor
 
processInFiler(ThrowableFunction<Filer, T>, BiFunction<Filer, Throwable, T>) - Method in class io.microsphere.annotation.processor.FilerProcessor
 
processInResource(String, boolean, ThrowableFunction<Optional<FileObject>, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResource(String, boolean, ThrowableFunction<Optional<FileObject>, T>, Function<Throwable, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceContent(String, ThrowableFunction<CharSequence, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceContent(String, ThrowableFunction<CharSequence, T>, BiFunction<FileObject, Throwable, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceInputStream(String, ThrowableFunction<InputStream, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceInputStream(String, ThrowableFunction<InputStream, T>, BiFunction<FileObject, Throwable, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceOutputStream(String, ThrowableConsumer<OutputStream>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceOutputStream(String, ThrowableConsumer<OutputStream>, BiConsumer<FileObject, Throwable>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceReader(String, ThrowableFunction<Reader, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceReader(String, ThrowableFunction<Reader, T>, BiFunction<FileObject, Throwable, T>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceWriter(String, ThrowableConsumer<Writer>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 
processInResourceWriter(String, ThrowableConsumer<Writer>, BiConsumer<FileObject, Throwable>) - Method in class io.microsphere.annotation.processor.ResourceProcessor
 

R

ResourceProcessor - Class in io.microsphere.annotation.processor
A processor class that provides a comprehensive and exception-safe mechanism for handling resources during annotation processing.
ResourceProcessor(ProcessingEnvironment, JavaFileManager.Location) - Constructor for class io.microsphere.annotation.processor.ResourceProcessor
 
ResourceProcessor(ProcessingEnvironment, JavaFileManager.Location, CharSequence) - Constructor for class io.microsphere.annotation.processor.ResourceProcessor
 
C E F G I P R 
All Classes All Packages